@@ -1,9 +1,9 @@
-/* Copyright (C) 1998, 1999, 2001 Thorsten Kukuk
+/* Copyright (C) 1998, 1999, 2000, 2001 Thorsten Kukuk
    This file is part of the yp-tools.
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License version 2 as 
+   it under the terms of the GNU General Public License version 2 as
    published by the Free Software Foundation.
 
    This program is distributed in the hope that it will be useful,
@@ -20,6 +20,8 @@
 #include "config.h"
 #endif
 
+#define _GNU_SOURCE
+
 #define keydat_val dptr
 #define keydat_len dsize
 #define valdat_val dptr
@@ -35,6 +37,7 @@
 #else
 #include "lib/getopt.h"
 #endif
+#include <time.h>
 #include <netdb.h>
 #include <limits.h>
 #include <string.h>
@@ -167,14 +170,16 @@ getnismaster (char *domainname, const char *progname)
   port = getrpcport (master, YPPASSWDPROG, YPPASSWDPROC_UPDATE, IPPROTO_UDP);
   if (port == 0)
     {
-      fprintf (stderr, _("%s: yppasswdd not running on NIS master host\n"),
-               progname);
+      fprintf (stderr,
+	       _("%s: yppasswdd not running on NIS master host (\"%s\").\n"),
+               progname, master);
       return NULL;
     }
   if (port >= IPPORT_RESERVED)
     {
-      fprintf (stderr, _("%s: yppasswd daemon running on illegal port.\n"),
-               progname);
+      fprintf (stderr,
+	       _("%s: yppasswd daemon running on illegal port (\"%s\").\n"),
+               progname, master);
       return NULL;
     }
 
@@ -247,7 +252,7 @@ ypgetpw (char *master, char *domainname, char *name, int uid)
 
   if (name == NULL)
     {
-      if (snprintf (uidbuf, sizeof (uidbuf), "%d", uid) > sizeof (uidbuf))
+      if (snprintf (uidbuf, sizeof (uidbuf), "%d", uid) >= sizeof (uidbuf))
 	abort ();
 
       keyval = strdup (uidbuf);
@@ -438,6 +443,7 @@ main (int argc, char **argv)
   uid_t uid;
 
   setlocale (LC_MESSAGES, "");
+  setlocale (LC_CTYPE, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 
@@ -575,17 +581,22 @@ main (int argc, char **argv)
       (pwd->pw_uid != uid))
     {
       char prompt[130];
+      char *hashpass, *cp;
 
       if (pwd->pw_uid != uid)
-        sprintf (prompt, _("Please enter root password:"));
+        snprintf (prompt, sizeof (prompt), _("Please enter root password:"));
       else
-        sprintf (prompt, _("Please enter %spassword:"),
-		 p_flag ? _("old ") : "");
+        snprintf (prompt, sizeof (prompt), _("Please enter %spassword:"),
+		  p_flag ? _("old ") : "");
       s = getpass (prompt);
+      hashpass = alloca (strlen (pwd->pw_name) + 3);
+      cp = stpcpy (hashpass, "##");
+      strcpy (cp, pwd->pw_name);
 
       /* We can't check the password with shadow passwords enabled. We
        * leave the checking to yppasswdd */
-      if (uid != 0 && strcmp (pwd->pw_passwd, "x") != 0)
+      if (uid != 0 && strcmp (pwd->pw_passwd, "x") != 0 &&
+	  strcmp (pwd->pw_passwd, hashpass ) != 0)
         if (strcmp (crypt (s, pwd->pw_passwd), pwd->pw_passwd))
           {
             fprintf (stderr, _("Sorry.\n"));
