@@ -1,6 +1,6 @@
-/* Copyright (C) 1998 Thorsten Kukuk
+/* Copyright (C) 1998, 1999 Thorsten Kukuk
    This file is part of the yp-tools.
-   Author: Thorsten Kukuk <kukuk@vt.uni-paderborn.de>
+   Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
