@@ -1,6 +1,6 @@
-/* Copyright (C) 1998 Thorsten Kukuk
+/* Copyright (C) 1998, 1999, 2001 Thorsten Kukuk
    This file is part of the yp-tools.
-   Author: Thorsten Kukuk <kukuk@vt.uni-paderborn.de>
+   Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -36,6 +36,11 @@
 #include <arpa/inet.h>
 #include "lib/yp-tools.h"
 
+#if defined (__NetBSD__) || (defined(__GLIBC__) && (__GLIBC__ == 2 && __GLIBC_MINOR__ == 0))
+/* <rpc/rpc.h> is missing the prototype */
+int getrpcport(char *host, int prognum, int versnum, int proto);
+#endif
+
 #ifndef _
 #define _(String) gettext (String)
 #endif
@@ -156,6 +161,7 @@ main (int argc, char **argv)
   char *hostname = NULL, *domainname = NULL;
 
   setlocale (LC_MESSAGES, "");
+  setlocale (LC_CTYPE, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 
